aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/client/linux/minidump_writer/linux_ptrace_dumper.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/client/linux/minidump_writer/linux_ptrace_dumper.cc b/src/client/linux/minidump_writer/linux_ptrace_dumper.cc
index f1582573..5ea3bd54 100644
--- a/src/client/linux/minidump_writer/linux_ptrace_dumper.cc
+++ b/src/client/linux/minidump_writer/linux_ptrace_dumper.cc
@@ -195,15 +195,15 @@ bool LinuxPtraceDumper::GetThreadInfoByIndex(size_t index, ThreadInfo* info) {
}
#if defined(__i386)
- // Detect if the CPU supports the MMX instructions
- int eax,ebx,ecx,edx;
- __cpuid(1,eax,ebx,ecx,edx);
- if (edx & bit_MMX) {
+ // Detect if the CPU supports the FXSAVE/FXRSTOR instructions
+ int eax, ebx, ecx, edx;
+ __cpuid(1, eax, ebx, ecx, edx);
+ if (edx & bit_FXSAVE) {
if (sys_ptrace(PTRACE_GETFPXREGS, tid, NULL, &info->fpxregs) == -1) {
return false;
}
} else {
- memset( &info->fpxregs, 0, sizeof(info->fpxregs) );
+ memset(&info->fpxregs, 0, sizeof(info->fpxregs));
}
#endif